@@ -17,6 +17,7 @@ import warnings
 
 import MDAnalysis as mda
 from MDAnalysis.analysis.base import AnalysisBase
+from MDAnalysis.transformations.boxdimensions import set_dimensions
 
 from .colors import Emphasise
 from .save import save_results
@@ -295,6 +296,18 @@ def add_cli_universe(parser, name=''):
         help="Override automatic trajectory type detection. "
         "See trajectory for implemented formats.")
 
+    parser.add_argument(
+        f"-dimensions{name}",
+        dest=f"dimensions{name}",
+        type=float,
+        default=None,
+        nargs="+",
+        help="Manually set/overwrite the simulation box dimensions to a "
+        "vector containing unit cell dimensions [a, b, c, α, β, γ], "
+        "lengths a, b, c are in Å, and angles α, β, γ are in degrees. "
+        "Providing only three parameters will assume a rectengular simulation "
+        "box (α = β = γ = 90°).")
+
 
 def create_CLI(sub_parser, interface_name, parameters):
     """
@@ -451,8 +464,9 @@ def create_CLI(sub_parser, interface_name, parameters):
 def create_universe(topology,
                     coordinates=None,
                     topology_format=None,
+                    trajectory_format=None,
                     atom_style=None,
-                    trajectory_format=None):
+                    dimensions=None):
     """
     Initilize a MDAnalysis universe instance.
 
@@ -489,6 +503,15 @@ def create_universe(topology,
     atom_style : str
         Customised LAMMPS `atom_style` information. Only works with
         `topology_format = data`
+    dimensions : iterable of floats
+        vector that contains unit cell lengths and probable angles.
+        Expected shapes are eithere (6, 0) or (1, 6) or for
+        shapes of (3, 0) or (1, 3) all angles are set to 90 degrees.
+
+    Raises
+    ------
+    IndexError
+        If the dimesions of the `dimensions` argument are not 3 or 6.
 
     Returns
     -------
@@ -501,6 +524,16 @@ def create_universe(topology,
     if coordinates is not None:
         universe.load_new(coordinates, format=trajectory_format)
 
+    if dimensions is not None:
+        if len(dimensions) == 3:
+            dimensions = [*dimensions, 90, 90, 90]
+        elif len(dimensions) != 6:
+            raise IndexError(
+                "The dimensions must contain at least 3 entries for "
+                "the box length and possibly 3 more entries for the angles.")
+
+        universe.trajectory.add_transformations(set_dimensions(dimensions))
+
     return universe
 
 
@@ -640,13 +673,9 @@ def convert_analysis_parameters(analysis_callable,
                                      f" `{analysis_parameters[param_name]}`"
                                      f" does not contain any atoms")
             elif "Universe" in dictionary['type']:
-
-                # All Universe parameters
-                universe_parameters = {"topology": None,
-                                       "coordinates": None,
-                                       "topology_format": None,
-                                       "atom_style": None,
-                                       "trajectory_format": None}
+                # Create universe parameter dictionary from signature
+                sig = inspect.signature(create_universe)
+                universe_parameters = dict(sig.parameters)
 
                 for k in universe_parameters.keys():
                     universe_parameters[k] = analysis_parameters.pop(
